@@ -28,6 +28,8 @@ def parse_requirements(requirements_str: str) -> dict:
     if isinstance(requirements_str, dict):
         return requirements_str
     assert isinstance(requirements_str, str), 'Invalid requirements type'
+    if requirements_str == "":
+        return dict()
     try:
         return json.loads(requirements_str)
     except json.decoder.JSONDecodeError:
@@ -39,5 +41,15 @@ def parse_requirements(requirements_str: str) -> dict:
             key, value = part.split('=')
             if not (key and value):
                 raise ValueError('value or key missing')
-            requirements[key] = value
+
+            def split(dest, subkey):
+                if '.' in subkey:
+                    keys = subkey.split('.')
+                    key1 = keys[0]
+                    rest = '.'.join(keys[1:])
+                    dest[key1] = {}
+                    split(dest[key1], rest)
+                else:
+                    dest[subkey] = value
+            split(requirements, key)
         return requirements
